import 'package:flutter/material.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:robot/robot.dart';

void main() {
  testWidgets('expectPositionedAtTop', (tester) async {
    final robot = Robot<Text>(tester);
    await tester.pumpWidget(
      const MaterialApp(
        home: Scaffold(
          body: Column(
            mainAxisSize: MainAxisSize.min,
            children: [
              Expanded(child: Text('Hello, World!')),
            ],
          ),
        ),
      ),
    );
    robot.expectPositionedAtTop();
  });

  testWidgets('expectPositionedAtTop using SafeArea', (tester) async {
    final robot = Robot<Text>(tester);
    await tester.pumpWidget(
      const MaterialApp(
        home: Scaffold(
          body: SafeArea(
            child: Column(
              mainAxisSize: MainAxisSize.min,
              children: [
                Expanded(child: Text('Hello, World!')),
              ],
            ),
          ),
        ),
      ),
    );
    robot.expectPositionedAtTop(usingSafeArea: true);
  });

  testWidgets('expectPositionedAtBottom using SafeArea', (tester) async {
    final robot = Robot<Text>(tester);
    await tester.pumpWidget(
      const MaterialApp(
        home: Scaffold(
          body: Column(
            mainAxisSize: MainAxisSize.min,
            children: [
              Expanded(child: Text('Hello, World!')),
            ],
          ),
        ),
      ),
    );
    robot.expectPositionedAtBottom();
  });

  testWidgets('expectPositionedAtBottom using SafeArea', (tester) async {
    final robot = Robot<Text>(tester);
    await tester.pumpWidget(
      const MaterialApp(
        home: Scaffold(
          body: SafeArea(
            child: Column(
              mainAxisSize: MainAxisSize.min,
              children: [
                Expanded(child: Text('Hello, World!')),
              ],
            ),
          ),
        ),
      ),
    );
    robot.expectPositionedAtBottom(usingSafeArea: true);
  });

  testWidgets('expectIsVerticallyAdjacentTo', (tester) async {
    final helloRobot = Robot<Text>.byKey(tester, const Key('hello'));
    final worldRobot = Robot<Text>.byKey(tester, const Key('world'));
    await tester.pumpWidget(
      const MaterialApp(
        home: Scaffold(
          body: Column(
            mainAxisSize: MainAxisSize.min,
            children: [
              Text('Hello', key: Key('hello')),
              Text('World!', key: Key('world')),
            ],
          ),
        ),
      ),
    );
    helloRobot.expectIsVerticallyAdjacentTo(worldRobot);
  });

  testWidgets('expectIsHorizontallyAdjacentTo', (tester) async {
    final helloRobot = Robot<Text>.byKey(tester, const Key('hello'));
    final worldRobot = Robot<Text>.byKey(tester, const Key('world'));
    await tester.pumpWidget(
      const MaterialApp(
        home: Scaffold(
          body: Row(
            mainAxisSize: MainAxisSize.min,
            children: [
              Text('Hello', key: Key('hello')),
              Text('World!', key: Key('world')),
            ],
          ),
        ),
      ),
    );
    helloRobot.expectIsHorizontallyAdjacentTo(worldRobot);
  });

  testWidgets('expectIsVerticallyCentered', (tester) async {
    final robot = Robot<Text>(tester);
    await tester.pumpWidget(
      const MaterialApp(
        home: Scaffold(
          body: Center(
            child: Text('Hello, World!'),
          ),
        ),
      ),
    );
    robot.expectIsVerticallyCentered();
  });

  testWidgets('expectIsHorizontallyCentered', (tester) async {
    final robot = Robot<Text>(tester);
    await tester.pumpWidget(
      const MaterialApp(
        home: Scaffold(
          body: Center(
            child: Text('Hello, World!'),
          ),
        ),
      ),
    );
    robot.expectIsHorizontallyCentered();
  });

  testWidgets('expectIsCentered', (tester) async {
    final robot = Robot<Text>(tester);
    await tester.pumpWidget(
      const MaterialApp(
        home: Scaffold(
          body: Center(
            child: Text('Hello, World!'),
          ),
        ),
      ),
    );
    robot.expectIsCentered();
  });

  testWidgets('expectIsCenteredIn', (tester) async {
    final robot = Robot<Text>(tester);
    await tester.pumpWidget(
      const MaterialApp(
        home: Scaffold(
          body: Center(
            child: Text('Hello, World!'),
          ),
        ),
      ),
    );
    robot.expectIsCenteredIn(find.byType(Center));
  });

  testWidgets('expectSpacedVerticallyTo', (tester) async {
    final helloRobot = Robot<Text>.byKey(tester, const Key('hello'));
    final worldRobot = Robot<Text>.byKey(tester, const Key('world'));
    await tester.pumpWidget(
      const MaterialApp(
        home: Scaffold(
          body: Column(
            mainAxisSize: MainAxisSize.min,
            children: [
              Text('Hello', key: Key('hello')),
              SizedBox(height: 10),
              Text('World!', key: Key('world')),
            ],
          ),
        ),
      ),
    );
    helloRobot.expectSpacedVerticallyTo(worldRobot, space: 10);
  });

  testWidgets('expectSpacedHorizontallyTo', (widgetTester) async {
    final helloRobot = Robot<Text>.byKey(widgetTester, const Key('hello'));
    final worldRobot = Robot<Text>.byKey(widgetTester, const Key('world'));
    await widgetTester.pumpWidget(
      const MaterialApp(
        home: Scaffold(
          body: Row(
            mainAxisSize: MainAxisSize.min,
            children: [
              Text('Hello', key: Key('hello')),
              SizedBox(width: 10),
              Text('World!', key: Key('world')),
            ],
          ),
        ),
      ),
    );
    helloRobot.expectSpacedHorizontallyTo(worldRobot, space: 10);
  });
}
